16.61. cdist-type__install_coreos(7) — cdist 4.10.11 documentation

# 16.61. cdist-type__install_coreos(7)

## 16.61.1. NAME

cdist-type__install_coreos - Install CoreOS

## 16.61.2. DESCRIPTION

This type installs CoreOS to a given device using coreos-install, which is present in CoreOS ISO by default.

## 16.61.3. REQUIRED PARAMETERS

device
  A device CoreOS will be installed to.

## 16.61.4. OPTIONAL PARAMETERS

ignition
  Path to ignition config.

## 16.61.5. EXAMPLES

    __install_coreos \
        --device /dev/sda \
        --ignition ignition.json

## 16.61.6. AUTHORS

Ľubomír Kučera <lubomir.kucera.jr at gmail.com>

## 16.61.7. COPYING

Copyright (C) 2018 Ľubomír Kučera. You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.